@@ -7,7 +7,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/golangci/golangci-lint/pkg/result"
+	"github.com/golangci/golangci-lint/v2/pkg/result"
 )
 
 type issueTestCase struct {
@@ -22,10 +22,12 @@ func newIssueFromIssueTestCase(c issueTestCase) result.Issue {
 	return result.Issue{
 		Text:       c.Text,
 		FromLinter: c.Linter,
+		Severity:   c.Severity,
 		Pos: token.Position{
 			Filename: c.Path,
 			Line:     c.Line,
 		},
+		RelativePath: c.Path,
 	}
 }
 
