@@ -8,8 +8,8 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/golangci/golangci-lint/pkg/config"
-	"github.com/golangci/golangci-lint/pkg/result"
+	"github.com/golangci/golangci-lint/v2/pkg/config"
+	"github.com/golangci/golangci-lint/v2/pkg/result"
 )
 
 var issues = []result.Issue{
@@ -209,28 +209,17 @@ func Test_numericCompare(t *testing.T) {
 	}
 }
 
-func TestSortResults_Process_noSorting(t *testing.T) {
+func TestSortResults_Process(t *testing.T) {
 	tests := make([]result.Issue, len(issues))
 	copy(tests, issues)
 
-	sr := NewSortResults(&config.Output{})
-
-	results, err := sr.Process(tests)
-	require.NoError(t, err)
-	assert.Equal(t, tests, results)
-}
-
-func TestSortResults_Process_Sorting(t *testing.T) {
-	tests := make([]result.Issue, len(issues))
-	copy(tests, issues)
-
-	cfg := &config.Output{SortResults: true}
+	cfg := &config.Output{}
 
 	sr := NewSortResults(cfg)
 
 	results, err := sr.Process(tests)
 	require.NoError(t, err)
-	assert.Equal(t, []result.Issue{issues[3], issues[2], issues[1], issues[0]}, results)
+	assert.Equal(t, []result.Issue{issues[1], issues[0], issues[3], issues[2]}, results)
 }
 
 func compToString(c int) string {
